from zrb import CmdTask, runner
from zrb.builtin.group import project_group

###############################################################################
# ⚙️ kebab-zrb-task-name
###############################################################################

snake_zrb_task_name = CmdTask(
    name='kebab-zrb-task-name',
    description='human readable zrb task name',
    group=project_group,
    cmd=[
        'echo human readable zrb task name'
    ]
)
runner.register(snake_zrb_task_name)



from zrb.helper.docstring import get_markdown_from_docstring
import re


def inject_doc(markdown_file_name: str, cls):
    docstring_markdown = get_markdown_from_docstring(cls)
    with open(markdown_file_name, 'r') as file:
        original_content = file.read()
    pattern = r'<!--start-doc-->.*?<!--end-doc-->'
    replacement_text = '\n'.join([
        '<!--start-doc-->',
        docstring_markdown,
        '<!--end-doc-->',
    ])
    new_content = re.sub(
        pattern, replacement_text, original_content, flags=re.DOTALL
    )
    with open(markdown_file_name, 'w') as file:
        file.write(new_content)



from zrb.helper.typecheck import typechecked
import libcst as cst


@typechecked
class AppendCodeTransformer(cst.CSTTransformer):
    def __init__(self, function_name: str, new_code: str):
        self.function_name = function_name
        self.new_code = new_code
        super().__init__()

    def leave_FunctionDef(
        self, original_node: cst.FunctionDef, updated_node: cst.FunctionDef
    ) -> cst.FunctionDef:
        if updated_node.name.value == self.function_name:
            new_body = updated_node.body.body + (
                cst.parse_statement(self.new_code),
            )
            return updated_node.with_changes(
                body=cst.IndentedBlock(body=new_body)
            )
        return updated_node


@typechecked
def append_code_to_function(
    code: str, function_name: str, new_code: str
) -> str:
    module = cst.parse_module(code)
    transformed_module = module.visit(
        AppendCodeTransformer(function_name, new_code)
    )
    return transformed_module.code
